@@ -22,22 +22,22 @@
 
 // Qt
 #include <QApplication>
-#include <QGraphicsLinearLayout>
 #include <QClipboard>
-
-// KDE
-#include <KLocale>
-#include <KConfigDialog>
-#include <psetables.h>
-
-// Plasma
-#include <plasma/theme.h>
-#include <KConfigGroup>
+#include <QGraphicsLinearLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 
+// KDE
+#include <KLocalizedString>
+#include <KConfigDialog>
+#include <KConfigGroup>
+
+// Plasma
+#include <Plasma/Theme>
+
 // local
+#include <psetables.h>
 
 Molmasscalculator::Molmasscalculator(QObject *parent, const QVariantList &args)
         : Plasma::PopupApplet(parent, args),
@@ -79,7 +79,7 @@ Molmasscalculator::~Molmasscalculator()
 
 void Molmasscalculator::init()
 {
-    // checking if the Dataengine is availiable
+    // checking if the Dataengine is available
     if (!dataEngine("kalzium")->isValid()) {
         setFailedToLaunch(true, i18n("Dataengine \"kalzium\" not found"));
     }
