@@ -19,12 +19,15 @@
 
 #include "concCalculator.h"
 
-#include <ktoolinvocation.h>
-#include "kalziumutils.h"
-#include <kunitconversion/converter.h>
-#include "prefs.h"
-#include <klocalizedstring.h>
 #include <QDebug>
+
+#include <KLocalizedString>
+#include <KToolInvocation>
+#include <KUnitConversion/Converter>
+
+#include "kalziumutils.h"
+#include "prefs.h"
+
 using namespace KUnitConversion;
 
 concCalculator::concCalculator(QWidget * parent) : QFrame(parent)
@@ -82,8 +85,8 @@ concCalculator::concCalculator(QWidget * parent) : QFrame(parent)
     connect(ui.mode, SIGNAL(activated(int)),
             this, SLOT(setMode(int)));
 
-    connect(ui.reset, SIGNAL(clicked()),
-            this, SLOT(init()));
+    connect(ui.reset, &QAbstractButton::clicked,
+            this, &concCalculator::init);
 
     /**************************************************************************/
     //              concentration Calculator setup complete
@@ -206,7 +209,7 @@ void concCalculator::calculateAmtSolute()
     // We have the amount of solvent in some form (moles, equivalents, mass, volume etc)
     // Now we have to present it in the UI
     switch (type2) {
-    case 0: // amount should be specified interms of mass
+    case 0: // amount should be specified in terms of mass
         switch (mode) {
         case 1: // we should get mass from moles
             massSolute = molesSolute * m_molarMass;
@@ -221,7 +224,7 @@ void concCalculator::calculateAmtSolute()
             break;
         }
         // update mass of solute
-        m_amtSolute = Value(massSolute, "grams");
+        m_amtSolute = Value(massSolute, KUnitConversion::Gram);
         m_amtSolute = m_amtSolute.convertTo(ui.amtSlt_unit->currentText());
         ui.amtSolute->setValue(m_amtSolute.number());
         break;
@@ -288,7 +291,6 @@ void concCalculator::calculateMolarMass()
     case 1:     // cannot be calculated (insufficient data)
         error(INSUFFICIENT_DATA_MOLE);
         return;
-        break;
     case 2:     // molality specified
         numMoles = massSolvent() / 1000.0 * m_concentration;
         break;
@@ -296,7 +298,6 @@ void concCalculator::calculateMolarMass()
     case 4:
         error(INSUFFICIENT_DATA_MOLE);
         return;
-        break;
     case 5:     // mole fraction specified
         numMoles = m_concentration / (100.0 - m_concentration) * molesSolvent();
         break;
@@ -328,7 +329,6 @@ void concCalculator::calculateEqtMass()
     case 0: // molarity not sufficient
         error(INSUFFICIENT_DATA_EQT);
         return;
-        break;
     case 1: // normality specified
         numEqts = volumeSolvent() * m_concentration;
         break;
@@ -338,7 +338,6 @@ void concCalculator::calculateEqtMass()
     case 5:
         error(INSUFFICIENT_DATA_EQT);
         return;
-        break;
     }
 
     if (type2 == 2) {    // Amount of solute specified in moles, cannot calculate
@@ -368,8 +367,7 @@ void concCalculator::calculateMolarMassSolvent()
     case 3:         // mass fraction specified
     case 4:         // volume fraction specified
         error(INSUFFICIENT_DATA_SOLVENT);
-        return;
-        break;      // cannot be calculated (insufficient data)
+        return;     // cannot be calculated (insufficient data)
     case 5:         // mole fraction specified
         numMoles = (100.0 - m_concentration) / m_concentration * molesSolute();
         break;
@@ -623,6 +621,7 @@ double concCalculator::volumeSolute()
         break;
     case 2:
         volume = massSolute() / densitySolute();
+        break;
     default:
         volume = 0;
         break;
@@ -873,7 +872,7 @@ void concCalculator::setMode(int mode)
         return;
     }
 
-    // set all to writeable
+    // set all to writable
     ui.amtSolute->setReadOnly(false);
     ui.molarMass->setReadOnly(false);
     ui.eqtMass->setReadOnly(false);
@@ -943,7 +942,7 @@ void concCalculator::error(int mode)
 {
     switch (mode) { // Depending on the mode, set the error messages.
     case RESET_CONC_MESSAGE:
-        ui.error->setText("");
+        ui.error->setText(QLatin1String(""));
         break;
     case PERCENTAGE:
         ui.error->setText(i18n("Percentage should be less than 100.0, please enter a valid value."));
