@@ -19,16 +19,17 @@ email                : cniehaus@kde.org
 #include "kalziumutils.h"
 
 #include <KLocalizedString>
+
+#include <QDebug>
 #include <QFile>
-#include <QPainter>
-#include <QSvgRenderer>
-#include <QRect>
 #include <QFileInfo>
 #include <QFontDatabase>
-#include <QDebug>
+#include <QPainter>
+#include <QRect>
+#include <QStandardPaths>
+#include <QSvgRenderer>
 
 #include <element.h>
-#include <QStandardPaths>
 #include "prefs.h"
 
 DetailedGraphicalOverview::DetailedGraphicalOverview(QWidget *parent)
@@ -84,7 +85,7 @@ void DetailedGraphicalOverview::paintEvent(QPaintEvent*)
     } else if (Prefs::colorschemebox() == 2) { //The iconic view is the 3rd view (0,1,2,...)
         pm.fill(palette().background().color());
 
-        QString pathname = QStandardPaths::locate(QStandardPaths::DataLocation, "data/iconsets/", QStandardPaths::LocateDirectory);
+        QString pathname = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
 
         int enumii = m_element->dataAsVariant(ChemicalDataObject::atomicNumber).toInt();
 
